==> zzyj-laborservice-impl-3.0.0-20250424.002805-88-sources.jar: com/ejianc/business/bid/bean/BidResultEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 劳务公司-投标结果登记
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_bid_result")
public class BidResultEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private String projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="bid_org_id")
    private Long bidOrgId; // 招标单位
    @TableField(value="bid_org_name")
    private String bidOrgName; // 招标单位名称
    @TableField(value="info_source")
    private Long infoSource; // 信息来源
    @TableField(value="plan_mny")
    private BigDecimal planMny; // 预计承揽金额
    @TableField(value="plan_mode")
    private String planMode; // 预计项目总规模
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="address")
    private String address; // 工程地点
    @TableField(value="province")
    private String province; // 省份
    @TableField(value="city")
    private String city; // 市
    @TableField(value="region")
    private String region; // 区县
    @TableField(value="adcode")
    private String adcode; // 区划编码
    @TableField(value="first_party")
    private Long firstParty; // 甲方
    @TableField(value="first_party_name")
    private String firstPartyName; // 甲方名称
    @TableField(value="first_party_type")
    private String firstPartyType; // 甲方单位性质
    @TableField(value="bidding_org")
    private Long biddingOrg; // 招标单位
    @TableField(value="bidding_org_name")
    private String biddingOrgName; // 招标单位名称
    @TableField(value="project_type")
    private String projectType; // 工程类型
    @TableField(value="bid_type")
    private String bidType; // 投标形式
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 投标价格
    @TableField(value="true_bid_mny")
    private BigDecimal trueBidMny; // 实际中标价格
    @TableField(value="bid_result")
    private String bidResult; // 开标结果
    @TableField(value="main_remark")
    private String mainRemark; // 主要情况描述
    @TableField(value="bid_id")
    private Long bidId; // 投标id
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public Long getBidOrgId() {
        return bidOrgId;
    }

    public void setBidOrgId(Long bidOrgId) {
        this.bidOrgId = bidOrgId;
    }
    public String getBidOrgName() {
        return bidOrgName;
    }

    public void setBidOrgName(String bidOrgName) {
        this.bidOrgName = bidOrgName;
    }
    public Long getInfoSource() {
        return infoSource;
    }

    public void setInfoSource(Long infoSource) {
        this.infoSource = infoSource;
    }
    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }
    public String getPlanMode() {
        return planMode;
    }

    public void setPlanMode(String planMode) {
        this.planMode = planMode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }
    public String getAdcode() {
        return adcode;
    }

    public void setAdcode(String adcode) {
        this.adcode = adcode;
    }
    public Long getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(Long firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getFirstPartyType() {
        return firstPartyType;
    }

    public void setFirstPartyType(String firstPartyType) {
        this.firstPartyType = firstPartyType;
    }
    public Long getBiddingOrg() {
        return biddingOrg;
    }

    public void setBiddingOrg(Long biddingOrg) {
        this.biddingOrg = biddingOrg;
    }
    public String getBiddingOrgName() {
        return biddingOrgName;
    }

    public void setBiddingOrgName(String biddingOrgName) {
        this.biddingOrgName = biddingOrgName;
    }
    public String getProjectType() {
        return projectType;
    }

    public void setProjectType(String projectType) {
        this.projectType = projectType;
    }
    public String getBidType() {
        return bidType;
    }

    public void setBidType(String bidType) {
        this.bidType = bidType;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public BigDecimal getTrueBidMny() {
        return trueBidMny;
    }

    public void setTrueBidMny(BigDecimal trueBidMny) {
        this.trueBidMny = trueBidMny;
    }
    public String getBidResult() {
        return bidResult;
    }

    public void setBidResult(String bidResult) {
        this.bidResult = bidResult;
    }
    public String getMainRemark() {
        return mainRemark;
    }

    public void setMainRemark(String mainRemark) {
        this.mainRemark = mainRemark;
    }
    public Long getBidId() {
        return bidId;
    }

    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }
    
}

==> zzyj-laborservice-impl-3.0.0-20251110.010756-96-sources.jar: com/ejianc/business/bid/bean/BidResultEntity.java <==
package com.ejianc.business.bid.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 劳务公司-投标结果登记
 * 
 * @author generator
 * 
 */
 @TableName("zzyj_laborservice_bid_result")
public class BidResultEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private String projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="service_date")
    private Date serviceDate; // 业务日期
    @TableField(value="bid_org_id")
    private Long bidOrgId; // 招标单位
    @TableField(value="bid_org_name")
    private String bidOrgName; // 招标单位名称
    @TableField(value="info_source")
    private Long infoSource; // 信息来源
    @TableField(value="plan_mny")
    private BigDecimal planMny; // 预计承揽金额
    @TableField(value="plan_mode")
    private String planMode; // 预计项目总规模
    @TableField(value="area")
    private String area; // 地区
    @TableField(value="address")
    private String address; // 工程地点
    @TableField(value="province")
    private String province; // 省份
    @TableField(value="city")
    private String city; // 市
    @TableField(value="region")
    private String region; // 区县
    @TableField(value="adcode")
    private String adcode; // 区划编码
    @TableField(value="first_party")
    private Long firstParty; // 甲方
    @TableField(value="first_party_name")
    private String firstPartyName; // 甲方名称
    @TableField(value="first_party_type")
    private String firstPartyType; // 甲方单位性质
    @TableField(value="bidding_org")
    private Long biddingOrg; // 招标单位
    @TableField(value="bidding_org_name")
    private String biddingOrgName; // 招标单位名称
    @TableField(value="project_type")
    private String projectType; // 工程类型
    @TableField(value="bid_type")
    private String bidType; // 投标形式
    @TableField(value="bid_mny")
    private BigDecimal bidMny; // 投标价格
    @TableField(value="true_bid_mny")
    private BigDecimal trueBidMny; // 实际中标价格
    @TableField(value="bid_result")
    private String bidResult; // 开标结果
    @TableField(value="main_remark")
    private String mainRemark; // 主要情况描述
    @TableField(value="bid_id")
    private Long bidId; // 投标id
    @TableField(value="apply_area")
    private String applyArea;//地区
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getProjectId() {
        return projectId;
    }

    public void setProjectId(String projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getServiceDate() {
        return serviceDate;
    }

    public void setServiceDate(Date serviceDate) {
        this.serviceDate = serviceDate;
    }
    public Long getBidOrgId() {
        return bidOrgId;
    }

    public void setBidOrgId(Long bidOrgId) {
        this.bidOrgId = bidOrgId;
    }
    public String getBidOrgName() {
        return bidOrgName;
    }

    public void setBidOrgName(String bidOrgName) {
        this.bidOrgName = bidOrgName;
    }
    public Long getInfoSource() {
        return infoSource;
    }

    public void setInfoSource(Long infoSource) {
        this.infoSource = infoSource;
    }
    public BigDecimal getPlanMny() {
        return planMny;
    }

    public void setPlanMny(BigDecimal planMny) {
        this.planMny = planMny;
    }
    public String getPlanMode() {
        return planMode;
    }

    public void setPlanMode(String planMode) {
        this.planMode = planMode;
    }
    public String getArea() {
        return area;
    }

    public void setArea(String area) {
        this.area = area;
    }
    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }
    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }
    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }
    public String getRegion() {
        return region;
    }

    public void setRegion(String region) {
        this.region = region;
    }
    public String getAdcode() {
        return adcode;
    }

    public void setAdcode(String adcode) {
        this.adcode = adcode;
    }
    public Long getFirstParty() {
        return firstParty;
    }

    public void setFirstParty(Long firstParty) {
        this.firstParty = firstParty;
    }
    public String getFirstPartyName() {
        return firstPartyName;
    }

    public void setFirstPartyName(String firstPartyName) {
        this.firstPartyName = firstPartyName;
    }
    public String getFirstPartyType() {
        return firstPartyType;
    }

    public void setFirstPartyType(String firstPartyType) {
        this.firstPartyType = firstPartyType;
    }
    public Long getBiddingOrg() {
        return biddingOrg;
    }

    public void setBiddingOrg(Long biddingOrg) {
        this.biddingOrg = biddingOrg;
    }
    public String getBiddingOrgName() {
        return biddingOrgName;
    }

    public void setBiddingOrgName(String biddingOrgName) {
        this.biddingOrgName = biddingOrgName;
    }
    public String getProjectType() {
        return projectType;
    }

    public void setProjectType(String projectType) {
        this.projectType = projectType;
    }
    public String getBidType() {
        return bidType;
    }

    public void setBidType(String bidType) {
        this.bidType = bidType;
    }
    public BigDecimal getBidMny() {
        return bidMny;
    }

    public void setBidMny(BigDecimal bidMny) {
        this.bidMny = bidMny;
    }
    public BigDecimal getTrueBidMny() {
        return trueBidMny;
    }

    public void setTrueBidMny(BigDecimal trueBidMny) {
        this.trueBidMny = trueBidMny;
    }
    public String getBidResult() {
        return bidResult;
    }

    public void setBidResult(String bidResult) {
        this.bidResult = bidResult;
    }
    public String getMainRemark() {
        return mainRemark;
    }

    public void setMainRemark(String mainRemark) {
        this.mainRemark = mainRemark;
    }
    public Long getBidId() {
        return bidId;
    }

    public void setBidId(Long bidId) {
        this.bidId = bidId;
    }

    public String getApplyArea() {

        return applyArea;
    }

    public void setApplyArea(String applyArea) {
        this.applyArea = applyArea;
    }
}
